@@ -64,8 +64,6 @@ class FlowMeter(object):
          * Total flow (only on models with the optional totalizer function)
          * Currently selected gas
 
-        Args:
-            retries: Number of times to re-attempt reading. Default 2.
         Returns:
             The state of the flow controller, as a dictionary.
 
@@ -191,7 +189,7 @@ class FlowController(FlowMeter):
         self.control_point = 'flow'
         asyncio.ensure_future(f())
 
-    async def get(self, retries=2):
+    async def get(self):
         """Get the current state of the flow controller.
 
         From the Alicat mass flow controller documentation, this data is:
@@ -204,13 +202,13 @@ class FlowController(FlowMeter):
          * Total flow (only on models with the optional totalizer function)
          * Currently selected gas
 
-        Args:
-            retries: Number of times to re-attempt reading. Default 2.
         Returns:
             The state of the flow controller, as a dictionary.
 
         """
-        state = await FlowMeter.get(self, retries)
+        state = await FlowMeter.get(self)
+        if state is None:
+            return None
         state['control_point'] = self.control_point
         return state
 
@@ -261,6 +259,8 @@ class FlowController(FlowMeter):
         """Get the control point, and save to internal variable."""
         command = '{addr}R122\r'.format(addr=self.address)
         line = await self._write_and_read(command)
+        if not line:
+            return None
         value = int(line.split('=')[-1])
         try:
             return next(p for p, r in self.registers.items() if value == r)
